# Generated by roxygen2: do not edit by hand

export(analyze_biofilm_sequence)
export(analyze_diversity)
export(analyze_growth)
export(analyze_social_behavior)
export(analyze_stability)
export(calculate_growth_params)
export(plot_growth_scatter)
export(plot_processed_curves)
export(summarize_social_behavior)
export(transform_curated_data)
export(transform_raw_data)
exportClasses(bsocial)
exportMethods(analyze_biofilm_sequence)
exportMethods(analyze_diversity)
exportMethods(analyze_growth)
exportMethods(analyze_social_behavior)
exportMethods(analyze_stability)
exportMethods(calculate_growth_params)
exportMethods(plot_growth_scatter)
exportMethods(plot_processed_curves)
exportMethods(summarize_social_behavior)
exportMethods(transform_curated_data)
exportMethods(transform_raw_data)
import(methods)
importFrom(dplyr,"%>%")
importFrom(grDevices,colorRampPalette)
importFrom(rlang,.data)
importFrom(stats,as.formula)
importFrom(stats,cor.test)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pairwise.t.test)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,head)
