% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bsocial-class.R
\name{summarize_social_behavior}
\alias{summarize_social_behavior}
\title{Classify Strains as Cooperators, Cheaters, or Neutrals}
\usage{
summarize_social_behavior(.Object, ...)
}
\arguments{
\item{.Object}{A \linkS4class{bsocial} object.}

\item{...}{Additional arguments.}
}
\value{
The modified \linkS4class{bsocial} object with
\code{resultados_analisis$summary_gen} and \code{resultados_analisis$summary_gr},
each a list with character vectors \code{positives} (cooperators),
\code{negatives} (cheaters), and \code{neutrals}.
}
\description{
Classify Strains as Cooperators, Cheaters, or Neutrals
}
