% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bsocial-class.R
\docType{class}
\name{bsocial-class}
\alias{bsocial-class}
\title{S4 Class for Microbial Social Behavior Analysis}
\description{
The \code{bsocial} class encapsulates data and results for analyzing microbial
social behavior in bacterial consortia.
}
\section{Slots}{

\describe{
\item{\code{id_proyecto}}{Character. Project identifier.}

\item{\code{cepas_seleccionadas}}{Character vector. Names of the selected strains.}

\item{\code{datos_crudos}}{List. Raw input data (plates, curated, consortia).}

\item{\code{datos_procesados}}{Data frame. Processed metrics (NGen, GR, LogPhase).}

\item{\code{resultados_analisis}}{List. Analysis results from each pipeline step.}

\item{\code{graficos}}{List. Generated ggplot2 plots and plotting functions.}
}}

\examples{
obj <- new("bsocial")
obj@id_proyecto <- "my_experiment"
}
